ResourceValidationError

Enum ResourceValidationError 

#[non_exhaustive]
pub enum ResourceValidationError { MissingResource { node: NodeId, system_name: &'static str, resource_type: &'static str, type_id: TypeId, access_mode: AccessMode, }, MissingOutput { node: NodeId, system_name: &'static str, output_type: &'static str, type_id: TypeId, }, ScopeMissingFactory { scope: NodeId, scope_name: &'static str, resource: &'static str, }, ScopeMissingResource { scope: NodeId, scope_name: &'static str, resource: &'static str, action: &'static str, }, }
Errors that can occur during resource validation.

These errors are detected before graph execution starts, allowing early detection of missing resources that would cause runtime failures.

Examples

use polaris_graph::ResourceValidationError;
use polaris_graph::NodeId;
use polaris_system::param::AccessMode;
use std::any::TypeId;

let err = ResourceValidationError::MissingResource {
    node: NodeId::from_string("node_1"),
    system_name: "my_system",
    resource_type: "MyConfig",
    type_id: TypeId::of::<String>(),
    access_mode: AccessMode::Read,
};

// Display provides a human-readable message
let msg = format!("{err}");
assert!(msg.contains("my_system"));
assert!(msg.contains("MyConfig"));

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MissingResource

A required resource is missing from the context.

Fields

node: NodeId

The node ID of the system requiring the resource.

system_name: &'static str

The name of the system.

resource_type: &'static str

The type name of the missing resource.

type_id: TypeId

The type ID of the missing resource.

access_mode: AccessMode

The access mode (read or write).



MissingOutput

A required output from a previous system is missing.

Fields

node: NodeId

The node ID of the system requiring the output.

system_name: &'static str

The name of the system.

output_type: &'static str

The type name of the missing output.

type_id: TypeId

The type ID of the missing output.



ScopeMissingFactory

A scope’s ContextPolicy declared forward_fresh::<T>() for a resource that has no registered factory in the parent context or globals.

Detected during GraphExecutor::validate_resources by walking the parent chain via SystemContext::factory_fn_by_type_id.

Fields

scope: NodeId

The scope node ID.

scope_name: &'static str

The scope node’s name.

resource: &'static str

The resource type that was missing a factory.



ScopeMissingResource

A scope’s ContextPolicy declared a per-resource crossing (forward::<T>() or fork::<T>()) for a resource that is not reachable from the parent context at validation time.

Detected during GraphExecutor::validate_resources via SystemContext::contains_resource_by_type_id. Mirrors the runtime ExecutionError::ScopeMissingResource safety net for callers that skip validation.

Fields

scope: NodeId

The scope node ID.

scope_name: &'static str

The scope node’s name.

resource: &'static str

The resource type that was missing.

action: &'static str

Which verb declared the crossing — "forward" or "fork".